=====================
Locust Documentation
=====================


Getting started
---------------

.. toctree ::
    :maxdepth: 2

    what-is-locust
    installation
    quickstart


Writing Locust tests
--------------------

.. toctree ::
    :maxdepth: 2

    writing-a-locustfile


Running your Locust tests
-------------------------

.. toctree ::
    :maxdepth: 1

    configuration
    increasing-request-rate
    running-distributed
    running-in-debugger
    running-in-docker
    running-without-web-ui


Other functionalities
---------------------

.. toctree ::
    :maxdepth: 2

    custom-load-shape
    retrieving-stats
    testing-other-systems
    increase-performance
    extending-locust
    logging
    use-as-lib
    extensions


Further reading / knowledgebase
-------------------------------

.. toctree ::
    :maxdepth: 1

    developing-locust
    further-reading
    faq


API
---
.. toctree ::
    :maxdepth: 2

    api



Changelog
---------

.. toctree ::
    :maxdepth: 2

    changelog
